/**************************************************************************************************
	Developed by: the Colorado Health Institute (CHI)
	Contact Information: 
		Rebecca Crepin
		720.382.7086
		crepinr@coloradohealthinstitute.org

	The 2010 Advanced Practice Nurse PUF data file was created with a 64-bit  
	version of SAS 9.2 on a 64-bit MS Windows operating system. If this data file will be 
	used with a 32-bit version of SAS 9.2 or earlier, the data file needs to be reassigned, 
	through a DATA STEP, so that it can subsequently assign the SAS formats correctly.

	The following code will execute the necessary DATA STEP described above and then assign 
	the SAS formats to the variables included in the RN PUF. 

	INPUT: apn10_puf.sas7bdat (64-bit SAS 9.2 data file from CHI)
	OUTPUT: a data file compatible with the user's version of SAS, with its associated SAS formats 

	NOTATION:
		>> USER INPUT <<;
		indicates all places in the beginning of the code where the user 
		should input information.
	
***************************************************************************************************/
options mprint mlogic symbolgen;
%global filename lib fmtlib;

************************** USER INPUT REQUIRED FOR THIS SECTION ONLY *******************************;

*>> USER INPUT <<;
* INSTRUCTIONS: provide a name for the SAS library associated with the location of the final 
* version of the data file
* (Example: lib = Survey);
%let lib = ;

*>> USER INPUT <<;
* INSTRUCTIONS: directory pathname for where the final version of the data file will be stored
* (Example: "C:\MyData");
libname &lib. "";

*>> USER INPUT <<;
* INSTRUCTIONS: name for FINAL version of the data file (it must have a different filename 
* than the CHI version if it will be stored in the SAME directory)
* (Example: filename = SurveyData);
%let filename = ;


*>> USER INPUT <<;
* INSTRUCTIONS: directory path name for where the CHI version of the PUF data file is located
* (Example: "C:\MyData\CHI");
libname LIB1 "";

*>> USER INPUT <<;
* INSTRUCTIONS: name for SAS library where the formats with be stored 
* (Example: fmtlib = rnfmt);
%let fmtlib = ;

*>> USER INPUT <<;
* INSTRUCTIONS: directory pathname for where format catalog will be stored
* (Example: "C:\MyData\Formats");
libname &fmtlib. "";

***************************************** END USER INPUT ******************************************
***************************************************************************************************;


options fmtsearch=(&fmtlib.);

* this DATA STEP will restructure the SAS data file to be compatible with user's version of SAS;
data &lib..&filename.; set lib1.apn10_puf; run;
proc format library=&fmtlib.;
value imp_notimp_grp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='Very Important'
2			='Somewhat/Not Important'
;
value sat_notsat_grp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='Very Satisfied (1,2,3)'
2			='(4,5,6,7)'
3			='Very Dissatified (8,9,10)'
;
value birth_yr_grp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='1945 or before'
2			='1946-1955'
3			='1956-1965'
4			='1966-1975'
5			='1976 or after'
;
value grad_yr_grp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='1980 or before'
2			='1981-1990'
3			='1991-2000'
4			='2001 or after'
;
value total_prac_mo_grp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='0-11 months'
2			='12-24 months'
3			='25-48 months'
4			='49-120 months'
5			='121-240 months'
6			='241-360 months'
7			='361 or more months'
;
value pct_grp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='0-25 percent'
2			='26-50 percent'
3			='51-75 percent'
4			='76-100 percent'
;
value pct_a_grp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='0-25 percent'
2			='26-100 percent'
;
value pct_b_grp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='0-10 percent'
2			='11-100 percent'
;
value pct_c_grp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='0-25 percent'
2			='26-50 percent'
3			='51-100 percent'
;
value pct_d_grp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='0-5 percent'
2			='6-10 percent'
3			='11-15 percent'
4			='16-100 percent'
;
value pct_e_grp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='0-5 percent'
2			='6-100 percent'
;
value pct_f_grp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='0 percent'
2			='1-100 percent'
;
value rx_authority_yr_grp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='1995 or before'
2			='1996-2000'
3			='2001-2005'
4			='2006-2010'
;
value race_grp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='White, not Hispanic'
2			='Hispanic/Latino'
3			='Multi-racial/multi-ethnic'
4			='Native American, Asian, African American or Native Hawaiian'
;
value state_grp
-9			="Missing"
-8			=">Not Applicable<"
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			="Colorado"
0			="Non-Colorado"
;
value educ_grp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='Bachelor''s of Science in Nursing'
2			='Master''s of Science in Nursing'
3			='Other Master''s Degree'
4			='Doctor of Nursing, Doctorate of Nursing Practice, or PhD in Nursing'
5			='Doctorate in another field'
6			='Other'
;
value nopa_grp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='Difficulty finding or unable to find a physician' 
2			='Currently completing my preceptorship or mentorship'
3			='Do not currently need prescriptive authority'
4			='Do not want to have prescriptive authority'
5			='Do not meet the criteria for having prescriptive authority'
;
value rsn_addpos_grp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='Was not offered fulltime work in principal APN position'
2			='To gain experience in a different aspect of advanced practice nursing'
3			='Other'
;
value hours_grp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='0-24 hours'
2			='25-36 hours'
3			='37-40 hours'
4			='More than 40 hours'
;
value hours_sec_grp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='0-10 hours'
2			='More than 10 hours'
;
value income_grp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='$40000 or less (or not working as an APN in 2009)'
2			='$40,001 to $50,000'
3			='$50,001 to $60,000'
4			='$60,001 to $70,000'
5			='$70,001 to $80,000'
6			='$80,001 to $90,000'
7			='$90,001 to $100,000'
8			='More than $100,000'
;
value setting_grp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='Acute care facility (hospital)/Ambulatory surgical center'
2			='Government or non-clinical setting'
3			='Private office or clinic'
4			='Outpatient clinic'
5			='Nursing home/Occupational health setting/rehabilitation facility'
6			='Other'
;
value timescale_grp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='Too little time'
2			='Just enough time'
3			='Too much time'
4			='N/A'
;
value freqscale_grp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='Always'
2			='Sometimes/Never'
;
value liability_grp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='Share cost with employer'
2			='Self'
3			='Practice/group'
4			='Hospital'
5			='Government or other'
;

value agegapn
-9 			= "Missing"
-8 			= ">Not Applicable<"
-7 			= ">Skip pattern violation<"
-6 			= ">Invalid answer/out of range<"
1 			= "34 years or younger"
2 			= "35 - 44 years"
3 			= "45 - 54 years"
4 			= "55 - 64 years"
5 			= "65 years or older"
;
value grdgapn
-9 			= "Missing"
-8 			= ">Not Applicable<"
-7 			= ">Skip pattern violation<"
-6 			= ">Invalid answer/out of range<"
1 			= "5 years or less"
2 			= "6 - 15 years"
3 			= "16 - 25 years"
4 			= "26 - 35 years"
5 			= "36 years or more"
;
value gageapn
-9 			= "Missing"
-8 			= ">Not Applicable<"
-7 			= ">Skip pattern violation<"
-6 			= ">Invalid answer/out of range<"
1 			= "25 years or younger"
2 			= "26 - 35 years"
3 			= "36 years or older"
;
value urban_grp
-9 			= "Missing"
-8 			= ">Not Applicable<"
-7 			= ">Skip pattern violation<"
-6 			= ">Invalid answer/out of range<"
1			="Isolated"
2			="Small Rural"
3			="Large Rural"
4			="Urban"
;
value apn_yesno
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
0			='No'
1			='Yes'
;
value gender
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='Female'
2			='Male'
;
value imp_notimp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='Very Important'
2			='Somewhat Important'
3			='Not Important'
;
value grewup
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='Urban'
2			='Rural'
3			='Suburban'
;
value addpos
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='Yes, work 2+ APN positions'
2			='Yes, work in 1+ RN positions in addition to APN position'
3			='No, work in only 1 APN position'
;
value probscale
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='Not a problem'
2			='Somewhat a problem'
3			='Significant problem'
;
value pctapn
-9			="Missing"
-8			=">Not Applicable<"
-7			=">Skip pattern violation<"
-6			=">Invalid answer/out of range<"
other		=[8.]
;
value acceptins
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='All'
2			='Some'
3			='None'
4			='Do Not Know'
;
value bill
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='Both directly and indirectly ("incident to"--under physician in practice)'
2			='Direct billing only (under physician in practice)'
3			='Indirect billing only ("incident to"--under physician in practice)'
4			='Do not know'
;
value interest
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='No'
2			='Undecided'
3			='Yes'
4			='Already a faculty member'
;
value urbanapn
-9 			= "Missing"
-8 			= ">Not Applicable<"
-7 			= ">Skip pattern violation<"
-6 			= ">Invalid answer/out of range<"
0			="Rural"
1			="Urban"
;
run;
proc datasets library = &lib.;
	modify &filename.;
	format satisf_career_grp satisf_compensate_grp sat_notsat_grp.;
	format birth_yr_grp birth_yr_grp.;
	format race_grp race_grp.;
	format grad_yr_grp grad_yr_grp.;
	format grad_state_grp principal_state_from_zip_grp secondary_state_from_zip_grp state_grp.;
	format principal_ruca2_from_zip_grp secondary_ruca2_from_zip_grp urban_grp.;
	format hours_all_grp hours_principal_grp total_hours_grp hours_grp.;
	format hours_secondary_grp hours_sec_grp.;
	format rsn_add_position_grp rsn_addpos_grp.;  
	format grad_numyrs_grp grdgapn.; 
	format grad_age_grp gageapn.; 
	format age_grp agegapn.;
	format total_prac_mo_grp total_prac_mo_grp.;
	format rx_authority_yr_grp rx_authority_yr_grp.;
	format rsn_no_pa_grp nopa_grp.;
	format income_grp income_grp.;
	format setting_grp setting_grp.;
	format highest_educ_grp educ_grp.; 
	format pays_liability_grp liability_grp.;
	format leave_rsn_no_respect_grp leave_rsn_wages_grp imp_notimp_grp.;
	format time_dir_patient_care_grp time_coll_patient_care_grp time_admin_grp time_meetings_grp 
		time_other_grp timescale_grp.;
	format principal_full_scope_grp principal_member_grp principal_reimb_grp principal_bill_grp 
		principal_pos_relation_grp principal_auto_decision_grp principal_cultural_grp 
		principal_high_quality_grp freqscale_grp.;
	format pct_time_direct_grp pct_priv_ins_grp pct_grp.;
	format pct_time_indirect_grp pct_a_grp.;
	format pct_time_other_grp pct_b_grp.;
	format pct_mdcr_grp pct_mdcd_grp pct_c_grp.;
	format pct_time_admin_grp   pct_d_grp.;
	format pct_wc_grp pct_uncompensated_grp pct_other_grp pct_chp_grp pct_tricare_grp 
		pct_time_teaching_grp pct_time_qual_improve_grp pct_time_cont_educ_grp pct_selfpay_grp pct_e_grp.;
	format pct_time_research_grp  pct_f_grp.;
	format gender	gender.;
	format grew_up_location	grewup.;
	format fluent CNA lpn adn bsn other_bacc other_mast phd_nursing	
		other_degree registr_crna registr_cns registr_np registr_cnm spec_acute_care spec_ad_prim_care	
		spec_ad_psych spec_ad_spec_care	spec_ch_psych spec_fam_prim_care spec_fam_psych	spec_gerontology	
		spec_anesthetist spec_midwife spec_neonatal	spec_ped_prim_care spec_ped_spec_care spec_wmn_health	
		spec_other cert_ad_np cert_crna cert_cnm cert_cns cert_fam_np cert_geriatric_np	cert_neonatal_np 
		cert_ped_np	cert_wmn_np	cert_other prescribe_sch_drugs rsn_no_sch_drugs_colleagues	
		rsn_no_sch_drugs_not_used rsn_no_sch_drugs_outofarea rsn_no_sch_drugs_concern rsn_no_sch_drugs_other	
		have_dea_num rsn_no_dea_nodesire rsn_no_dea_noneed rsn_no_dea_fee employed_co no_work_prim_hc_no_apn			
		no_work_hc_related_no_apn no_work_lack_respect no_work_wages no_work_no_positions no_work_family			
		no_work_retired	no_work_other indep_prac listed_provider hosp_admit_priv pct_dontknow mdcr_pn mdcd_pn		
		npi	leave_12mo interest_cna	interest_lpn interest_adn interest_bsn interest_msn	interest_dnp 
		interest_other						
		rx_authority yesno.;			
	format	prac_policy_refl_apn hosp_policy_refl_apn reimb_policy state_pilot indep_incentive loan_forgive				
		consensus_md_apn imp_notimp.;
	format	grew_up_location grewup.;
	format 	another_position addpos.;
	format	prob_time prob_communicate prob_specialists	prob_reports prob_priv_ins prob_pay	prob_liability_ins	
		prob_call_coverage	probscale.;
	format pct_time_total pct_total pctapn.;
	format	accept_new_priv_ins	accept_new_family accept_new_uninsured accept_new_slide_fee	accept_new_ad_mdcd	
		accept_new_ch_mdcd accept_new_wmn_chp accept_new_ch_chp	accept_new_mdcr	accept_new_wc 
		accept_new_charity acceptins.;
	format services_billed	bill.;	
	format interest_faculty interest.;
	format	principal_urban_from_zip secondary_urban_from_zip urbanapn.;		
;
quit;
